ImageLayer
==========

.. currentmodule:: pywwt.layers

.. autoclass:: ImageLayer
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~ImageLayer.cmap
      ~ImageLayer.opacity
      ~ImageLayer.stretch
      ~ImageLayer.vmax
      ~ImageLayer.vmin

   .. rubric:: Methods Summary

   .. autosummary::

      ~ImageLayer.remove

   .. rubric:: Attributes Documentation

   .. autoattribute:: cmap
   .. autoattribute:: opacity
   .. autoattribute:: stretch
   .. autoattribute:: vmax
   .. autoattribute:: vmin

   .. rubric:: Methods Documentation

   .. automethod:: remove
